//******************************************************************************
//  ES437 SerialFlash and DAC7512 Demo Module
//
//	by
//  SoftBaugh, Inc.
//  June 2004
//  Built with IAR Embedded Workbench V2
//
//  This demo controls both the Serial Flash and the DAC on the ESG439.
//      SST25VF:  A Read-ID sequence is performed by sending the SST25VF a 
//                Read-ID command.  The SST25VF should return a 43h.  If 
//                43h is received P1.0 is set low, thus turning on D1. 
//                Otherwise P1.0 is set high, turning D1 off.
//
//      DAC7512N: Commands are sent to the DAC7512 to ouput a crude 
//                triangle wave.
//              
//******************************************************************************

#include "msp430x43x.h"
#include "Command.h"
#include "SST25VF.h"

void InitializeHardware( void );

void main( void )
{
    WDTCTL = WDTPW + WDTHOLD;             // Stop WDT

	InitializeHardware();
	Command_Init();
	SST25VF_Init();

	_EINT();    // Enable interrupts

    Command_Loop();
 
}

void InitializeHardware( void )
{
	FLL_CTL0 |= XCAP18PF;       // Set load capacitance for xtal
	
	// Setup port functions
	P1SEL = 0x32;		// Output P1.0(LED), P1.1 (MCLK), P1.4 (SMCLK), P1.5 (ACLK)
	P1DIR = 0x33;		 
	P1OUT = 0xFE;		 

	//No P2 Setup

	//P3 Setup
	P3SEL = 0x0E;		  // P3.0 = STE0, P3.1 = MOSI, P3.2 = MISO, P3.3 = SCLK
	P3DIR = 0x9B;		 //P3.4 as sync output for DAC
	P3OUT = 0x0B;	
	
	// No P4 setup
	// No P5 setup
	// No P6 setup	
}

void DAC_Tick(void)
{ 
        SST25VF_OutDAC(0x000);
        SST25VF_OutDAC(0x1C7);
        SST25VF_OutDAC(0x38E);
        SST25VF_OutDAC(0x555);
        SST25VF_OutDAC(0x71C);
        SST25VF_OutDAC(0x8E3);
        SST25VF_OutDAC(0xAAA);
        SST25VF_OutDAC(0xC71);
        SST25VF_OutDAC(0xE38);
        SST25VF_OutDAC(0xFFF);
        SST25VF_OutDAC(0xE38);
        SST25VF_OutDAC(0xC71); 
        SST25VF_OutDAC(0xAAA);
        SST25VF_OutDAC(0x8E3);
        SST25VF_OutDAC(0x71C);
        SST25VF_OutDAC(0x555);
        SST25VF_OutDAC(0x38E);
        SST25VF_OutDAC(0x1C7);
}

