//******************************************************************************
//  SST25VF Driver Module
//
//	by
//  SoftBaugh, Inc.
//  June 2004
//  Built with IAR Embedded Workbench V2
//******************************************************************************

#include "msp430x43x.h"
#include "SST25VF.h"

#define CMD_READ_STATUS_REGISTER        0x05
#define CMD_READ_CHIP_ID		0x90
void SST25VF_EnableSPI( void );
void SST25VF_DisableSPI( void );
unsigned int SST25VF_ExecuteSPI( unsigned int nArg );

void SST25VF_Init( void )
{
	//*********** USART0 initialization for SPI communications ***********
	ME1 |= USPIE0;					// Enable USART0 SPI mode
	UCTL0 = CHAR+SYNC+MM;			// 8-bit SPI Master **SWRST** see page 13-16 TI slau049b.pdf
	U0TCTL = CKPL+SSEL1+SSEL0+STC;	// SelectSMCLK and 3-pin SPI select??
	UBR00 = 0x04;					// UCLK/2
	UBR10 = 0x00;					// 0
	UMCTL0 = 0x00;                  // no modulation  
									
	// Setup P3 for SPI0 operation
	P3SEL |= 0x0E;		// P3.1-3 SPI option select
	P3DIR |= 0x01;		// P3.0 output direction
	P3OUT |= 0x01;		// CS high
}

unsigned int SST25VF_ReadStatusRegister( void )
{	unsigned int nResult;

	SST25VF_EnableSPI();
	SST25VF_ExecuteSPI( CMD_READ_STATUS_REGISTER );
	nResult = SST25VF_ExecuteSPI( 0x00 );
	SST25VF_DisableSPI();

	return nResult;		
}

unsigned int SST25VF_ReadChipID( void )
{	unsigned int nResult;

	SST25VF_EnableSPI();
	SST25VF_ExecuteSPI( CMD_READ_CHIP_ID );
	SST25VF_ExecuteSPI( 0x00 );
	SST25VF_ExecuteSPI( 0x00 );
	SST25VF_ExecuteSPI( 0x01 );
	nResult = SST25VF_ExecuteSPI( 0x00 );
	SST25VF_DisableSPI();
        
	return nResult;		
}

unsigned int SST25VF_ReadMfgID( void )
{	unsigned int nResult;

	SST25VF_EnableSPI();
	SST25VF_ExecuteSPI( CMD_READ_CHIP_ID );
	SST25VF_ExecuteSPI( 0x00 );
	SST25VF_ExecuteSPI( 0x00 );
	SST25VF_ExecuteSPI( 0x00 );
	nResult = SST25VF_ExecuteSPI( 0x00 );
	SST25VF_DisableSPI();

	return nResult;		
}

unsigned int SST25VF_OutDAC( int nValue )
{	unsigned int nResult = 0;

	P3OUT &= ~0x10;		  //Set DAC SYNC low
	SST25VF_ExecuteSPI( nValue>>8 );
	SST25VF_ExecuteSPI( nValue & 0xFF );
	P3OUT |= 0x10;          //Set DAC SYNC high

	return nResult;		
}

// Private module functions to manipulate SPI
void SST25VF_EnableSPI( void )
{	P3OUT &= ~0x01;			// Set CS low
}

void SST25VF_DisableSPI( void )
{	P3OUT |= 0x01;			// Set CS high
}

unsigned int SST25VF_ExecuteSPI( unsigned int nArg )
{	unsigned int nResult;
    
	while ((IFG1 & UTXIFG0) == 0);	// USART0 TX buffer ready?

    IFG1 &= ~URXIFG0;			// Clear Rx flag

	// Exchange byte
	TXBUF0 = nArg & 0xFF;
	while ((IFG1 & UTXIFG0) == 0);
	while ((IFG1 & URXIFG0) == 0);
	nResult = RXBUF0;

	return nResult;			
}

